@@ -7,7 +7,19 @@ from discord.ext.commands.bot import BotBase
 from discord.ext.commands import Cog
 from discord.ext import commands
 
-logger = logging.getLogger("discordn")
+logger = logging.getLogger(__package__)
+
+
+old_init = BotBase.__init__
+
+
+def init(self, *args, extensions=(), cogs=(), **kwargs):
+    old_init(self, *args, **kwargs)
+
+    for p in extensions:
+        self.load_extension(p)
+    for p in cogs:
+        self.load_extension(p)
 
 
 class BadMultilineCommand(commands.errors.CommandError):
@@ -26,6 +38,12 @@ async def process_commands(self, message):
     if message.author.bot:
         return
 
+    # F*** smart quotes.
+    message.content = message.content.replace("“", "\"")
+    message.content = message.content.replace("”", "\"")
+    message.content = message.content.replace("’", "'")
+    message.content = message.content.replace("‘", "'")
+
     contexts = []
 
     ctx = await self.get_context(message)
@@ -72,22 +90,6 @@ async def process_commands(self, message):
         await self.invoke(ctx)
 
 
-old_dispatch = BotBase.dispatch
-first_ready = True
-
-
-def dispatch(self, event_name, *args, **kwargs):
-    global first_ready
-    old_dispatch(self, event_name, *args, **kwargs)
-    if event_name == "ready":
-        if first_ready:
-            event_name = "first_ready"
-            first_ready = False
-        else:
-            event_name = "reconnect_ready"
-        old_dispatch(self, event_name, *args, **kwargs)
-
-
 def formatTraceback(err) -> str:
     return "".join(traceback.format_exception(type(err), err, err.__traceback__))
 
@@ -176,9 +178,17 @@ async def on_command_error(self, ctx, exception):
 on_command_error.emojis = Emojis
 
 
+async def on_message_edit(self, before, after):
+    # run editted commands
+    if before.content == after.content:
+        return
+    await self.process_commands(after)
+
+
 def patch():
     commands.errors.BadMultilineCommand = BadMultilineCommand
     commands.BadMultilineCommand = BadMultilineCommand
+    BotBase.__init__ = init
     BotBase.process_commands = process_commands
-    BotBase.dispatch = dispatch
     BotBase.on_command_error = on_command_error
+    BotBase.on_message_edit = on_message_edit
